Advanced Topics
===============

Provisioning in LinchPin is a fairly simple process. However, LinchPin also
provides some very flexible and powerful features. These features can
sometimes be complex, which means most users will likely not use them. Those
features are covered here.

.. toctree::
   :maxdepth: 1

   advanced/layouts
   advanced/rundb
   advanced/journal
   advanced/context_distiller
   advanced/cfgs
